@@ -13,7 +13,7 @@
 ##' @rdname colSums
 ##' @name colSums
 NULL
- 
+
 ##' @noRd
 setGeneric ('colMeans')#, package = 'matrixStats')
 
@@ -27,14 +27,7 @@ setGeneric ('colMeans')#, package = 'matrixStats')
       result <- t (result)
 
    decomposition (x, result, scores = FALSE, label.spc = label.spc)
-}) 
-
-.test (colMeans) <- function (){
-  checkEqualsNumeric (colMeans (flu)[[]], colMeans (flu [[]]))
-  
-  checkEqualsNumeric (colMeans (fluNA)[[]], colMeans (fluNA [[]], na.rm = TRUE))
-  checkEqualsNumeric (colMeans (fluNA, na.rm = FALSE)[[]], colMeans (fluNA [[]], na.rm = FALSE))
-}
+})
 
 ##' @noRd
 setGeneric ('colSums') #, package = 'matrixStats')
@@ -49,14 +42,8 @@ setMethod ("colSums", signature = signature (x = "hyperSpec"), function (x, na.r
       result <- t (result)
 
    decomposition (x, result, scores = FALSE, label.spc = label.spc)
-}) 
+})
 
-.test (colSums) <- function (){
-  checkEqualsNumeric (colSums (flu)[[]], colSums (flu [[]]))
-
-  checkEqualsNumeric (colSums (fluNA)[[]], colSums (fluNA [[]], na.rm = TRUE))
-  checkEqualsNumeric (colSums (fluNA, na.rm = FALSE)[[]], colSums (fluNA [[]], na.rm = FALSE))
-}
 
 ##' @noRd
 setGeneric ('rowMeans') #, package = 'matrixStats')
@@ -71,14 +58,7 @@ setMethod ("rowMeans", signature = signature (x = "hyperSpec"), function (x, na.
       result <- t (result)
 
    decomposition (x, result, scores = TRUE, label.wavelength = label.wavelength)
-}) 
-
-.test (rowMeans) <- function (){
-  checkEqualsNumeric (rowMeans (flu)[[]], rowMeans (flu [[]]))
-
-  checkEqualsNumeric (rowMeans (fluNA)[[]], rowMeans (fluNA [[]], na.rm = TRUE))
-  checkEqualsNumeric (rowMeans (fluNA, na.rm = FALSE)[[]], rowMeans (fluNA [[]], na.rm = FALSE))
-}
+})
 
 ##' @noRd
 setGeneric ('rowSums') #, package = 'matrixStats')
@@ -93,12 +73,23 @@ setMethod ("rowSums", signature = signature (x = "hyperSpec"), function (x, na.r
       result <- t (result)
 
    decomposition (x, result, scores = TRUE, label.wavelength = label.wavelength)
-}) 
+})
 
-.test (rowSums) <- function (){
-  checkEqualsNumeric (rowSums (flu)[[]], rowSums (flu [[]]))
+##' @include unittest.R
+.test (colMeans) <- function (){
 
-  checkEqualsNumeric (rowSums (fluNA)[[]], rowSums (fluNA [[]], na.rm = TRUE))
-  checkEqualsNumeric (rowSums (fluNA, na.rm = FALSE)[[]], rowSums (fluNA [[]], na.rm = FALSE))
+  for (fun in c ("colMeans", "colSums", "rowMeans", "rowSums")){
+    context (fun)
+    f <- get (fun, mode = "function")
+    test_that("basic operation", {
+      expect_equal (as.numeric (f (flu)                 [[]]), f (flu [[]])                 , label = fun)
+    })
+
+    test_that("behaviour with NAs", {
+      expect_equal (as.numeric (f (fluNA)               [[]]), f (fluNA [[]], na.rm = TRUE ), label = fun)
+      expect_equal (as.numeric (f (fluNA, na.rm = FALSE)[[]]), f (fluNA [[]], na.rm = FALSE), label = fun)
+    })
+
+  }
 }
 
