@@ -11,24 +11,24 @@
 ##' Plot the spectra of a \code{hyperSpec} object, i.e. intensity over
 ##' wavelength. Instead of the intensity values of the spectra matrix summary
 ##' values calculated from these may be used.
-##' 
+##'
 ##' This is \code{hyperSpec}'s main plotting function for spectra plots.
-##' 
+##'
 ##' New plots are created by \code{\link[graphics]{plot}}, but the abscissa and
 ##' ordinate are drawn separately by \code{\link[graphics]{axis}}. Also,
 ##' \code{\link[graphics]{title}} is called explicitly to set up titles and
 ##' axis labels. This allows fine-grained customization of the plots.
-##' 
+##'
 ##' If package plotrix is available, its function
 ##' \code{\link[plotrix]{axis.break}} is used to produce break marks for cut
 ##' wavelength axes.
-##' 
+##'
 ##' @param object the \code{hyperSpec} object
 ##' @param wl.range the wavelength range to be plotted.
-##' 
+##'
 ##' Either a numeric vector or a list of vectors with different wavelength
 ##'   ranges to be plotted separately.
-##' 
+##'
 ##' The values can be either wavelengths or wavelength indices (according to
 ##'   \code{wl.index}).
 ##' @param wl.index if \code{TRUE}, \code{wl.range} is considered to give
@@ -47,7 +47,7 @@
 ##' @param xoffset vector with abscissa offsets for each of the
 ##'   \code{wl.range}s. If it has one element less than there are
 ##'   \code{wl.range}s, 0 is padded at the beginning.
-##' 
+##'
 ##' The values are interpreted as the distance along the wavelength axis that
 ##'   the following parts of the spectra are shifted towards the origin. E.g.
 ##'   if \code{wl.range = list (600 ~ 1800, 2800 ~ 3200)}, \code{xoffset = 750}
@@ -66,7 +66,7 @@
 ##'   filled with color \code{col}. The grouping can be given as factor or
 ##'   numeric, or as a character with the name of the extra data column to use.
 ##'   If a group contains more than 2 spectra, the first and the last are used.
-##' 
+##'
 ##' If \code{TRUE} spectra n and nrow (spc) - n build a group.
 ##' @param fill.col character vector with fill color. Defaults to brightened
 ##'   colors from \code{col}.
@@ -80,12 +80,12 @@
 ##'   (again as \code{lists}).
 ##' @param title.args list with further arguments to
 ##'   \code{\link[graphics]{title}}.
-##' 
+##'
 ##' \code{title.args} may contain two lists, \code{$x}, and \code{$y} to set
 ##'   parameters individually for each axis.
 ##' @param lines.args list with further arguments to
 ##'   \code{\link[graphics]{lines}}.
-##' 
+##'
 ##' \code{lines.args$type} defaults to "l".
 ##' @param break.args list with arguments for
 ##'   \code{\link[plotrix]{axis.break}}.
@@ -93,55 +93,57 @@
 ##'   \code{\link[graphics]{polygon}} which draws the filled areas.
 ##' @param zeroline \code{NA} or a list with arguments
 ##'   \code{\link[graphics]{abline}}, used to plot line (s) marking I = 0.
-##' 
+##'
 ##' \code{NA} suppresses plotting of the line.  The line is by default turned
 ##'   off if \code{yoffset} is not 0.
+##' @param debuglevel if > 0, additional debug output is produced,
+##' see \code{\link[hyperSpec]{options}} for details
 ##' @return \code{plotspc} invisibly returns a list with
-##' 
+##'
 ##' \item{x}{the abscissa coordinates of the plotted spectral data points}
-##' 
+##'
 ##' \item{y}{a matrix the ordinate coordinates of the plotted spectral data
 ##'   points}
-##' 
+##'
 ##' \item{wavelengths}{the wavelengths of the plotted spectral data points}
-##' 
+##'
 ##' This can be used together with \code{\link{spc.identify}}.
 ##' @author C. Beleites
 ##' @seealso \code{\link[graphics]{plot}}, \code{\link[graphics]{axis}},
 ##'   \code{\link[graphics]{title}}, \code{\link[graphics]{lines}},
 ##'   \code{\link[graphics]{polygon}}, \code{\link[graphics]{par}} for the
 ##'   description of the respective arguments.
-##' 
+##'
 ##' \code{\link[plotrix]{axis.break}} for cut marks
-##' 
+##'
 ##' See \code{\link{plot}} for some predefined spectra plots such as mean
 ##'   spectrum +/- one standard deviation and the like.
-##' 
+##'
 ##' \code{\link[graphics]{identify}} and \code{\link[graphics]{locator}} about
 ##'   interaction with plots.
 ##' @keywords hplot
 ##' @export
 ##' @examples
-##' 
+##'
 ##' plotspc (flu)
-##' 
+##'
 ##' ## artificial example to show wavelength axis cutting
 ##' plotspc (chondro [sample (nrow (chondro), 50)],
 ##'          wl.range = list (600 ~ 650, 1000 ~ 1100, 1600 ~ 1700),
 ##'          xoffset = c (0, 300, 450))
-##' 
+##'
 ##' plotspc (chondro [sample (nrow (chondro), 50)],
 ##'          wl.range = list (600 ~ 650, 1000 ~ 1100, 1600 ~ 1700),
 ##'          xoffset = c (300, 450))
-##' 
+##'
 ##' ## some journals publish Raman spectra backwards
 ##' plotspc (chondro [sample (nrow (chondro), 50)], wl.reverse = TRUE)
-##' 
+##'
 ##' plotspc (laser[(0:4)*20+1,,], stacked = TRUE)
-##' 
-##' plotspc (laser, func = mean_pm_sd, 
+##'
+##' plotspc (laser, func = mean_pm_sd,
 ##'          col = c(NA, "red", "black"), lines.args = list (lwd = 2),
-##'          fill = c (1, NA, 1), 
+##'          fill = c (1, NA, 1),
 ##'          fill.col = "yellow", border = "blue",
 ##'          polygon.args = list (lty = 2, lwd = 4),
 ##'          title.args = list (xlab = expression (lambda[emission] / nm),
@@ -149,17 +151,18 @@
 ##'                             col.lab = "darkgreen"),
 ##'          axis.args = list (x = list (col = "magenta"), y = list (las = 1))
 ##'         )
-##'         
+##'
 ##' mean.pm.sd <- aggregate (chondro, chondro$clusters, mean_pm_sd)
 ##' plot (mean.pm.sd, col = matlab.palette (3), fill = ".aggregate", stacked = ".aggregate")
-##' 
+##'
 ##' @importFrom utils modifyList relist head tail
 ##' @importFrom grDevices rgb col2rgb
 plotspc <- function  (object,
                        ## what wavelengths to plot
                       wl.range = NULL, wl.index = FALSE,  wl.reverse = FALSE,
                       ## what spectra to plot
-                      spc.nmax = 50, func = NULL, func.args = list (),
+                      spc.nmax = hy.getOption("plot.spc.nmax"),
+                      func = NULL, func.args = list (),
                       stacked = NULL, stacked.args = list (),
                       ## plot area
                       add = FALSE, bty = "l", plot.args = list(),
@@ -173,9 +176,10 @@ plotspc <- function  (object,
                       ## parameters for filled regions
                       fill = NULL, fill.col = NULL, border = NA, polygon.args = list (),
                       ## line indicating zero intensity
-                      zeroline = list (lty = 2, col = col)){
+                      zeroline = list (lty = 2, col = col),
+                      debuglevel = hy.getOption("debuglevel")){
   force (zeroline) # otherwise stacking messes up colors
-  
+
   chk.hy (object)
   validObject (object)
   if (nrow (object) == 0) stop ("No spectra.")
@@ -186,7 +190,7 @@ plotspc <- function  (object,
     wl.range <- seq_along (object@wavelength)
     wl.index <- TRUE
   }
-  
+
   if (!is.list (wl.range))
     wl.range <- list (wl.range)
 
@@ -246,8 +250,9 @@ plotspc <- function  (object,
   ## do not plot too many spectra by default: can take very long and there is most probably nothing
   ## visible on the resulting picture
   if (nrow (spc) > spc.nmax){
-    warning (paste ("Number of spectra exceeds spc.nmax. Only the first",
-                    spc.nmax, "are plotted."))
+    if (debuglevel >= 1L)
+      message ("Number of spectra exceeds spc.nmax. Only the first", spc.nmax, "are plotted.")
+
     spc <- spc [seq_len (spc.nmax), , drop = FALSE]
   }
 
@@ -255,7 +260,7 @@ plotspc <- function  (object,
   if (!is.null (stacked)){
     stacked.args <- modifyList (stacked.args,
                                 list (x = object, stacked = stacked, .spc = spc))
-    
+
     if (! is.null (lines.args$type) && lines.args$type == "h")
       stacked.args <- modifyList (stacked.args, list (min.zero = TRUE))
 
@@ -277,7 +282,7 @@ plotspc <- function  (object,
     else
       stop ("yoffset must be single number or one number for each spectrum (or stacking group).")
   }
-  
+
   spc <- sweep (spc, 1, yoffset, "+")
 
   ## plot area --------------------------------------------------------------------------------------
@@ -288,7 +293,7 @@ plotspc <- function  (object,
     plot.args <- modifyList (list (xlim = range (unlist (x), na.rm = TRUE),
                                    ylim = range (spc, na.rm = TRUE)),
                              plot.args)
-    
+
     ## the actual spectra are plotted below, so we do not need any line parametrers here
 
     ## reverse x axis ?
@@ -299,13 +304,13 @@ plotspc <- function  (object,
     plot.args <- modifyList (plot.args,
                              list (x = unlist (x), y = spc[1,,drop=FALSE],
                                    type = "n", bty = "n",
-                                   xaxt = "n", yaxt = "n", # axes and title are called separately 
+                                   xaxt = "n", yaxt = "n", # axes and title are called separately
                                    xlab = NA,  ylab = NA)) # for finer control
-    
+
     do.call (plot, plot.args)
 
                              ## reversed x axis leads to trouble with tick positions
-                             ## 
+                             ##
     if (diff (plot.args$xlim) < 0)
       plot.args$xlim <- rev(plot.args$xlim)
 
@@ -315,7 +320,7 @@ plotspc <- function  (object,
     ## x-axis labels & ticks
     if (bty %in% c("o", "l", "c", "u", "]", "x") ){
       cuts <- .cut.ticks (sapply (wavelengths, min), sapply (wavelengths, max), xoffset, nxticks)
-      
+
       axis.args$x <- modifyList (axis.args [! names (axis.args) %in% c ("x", "y")],
                                  axis.args$x)
       if (is.null (axis.args$x$labels) & ! is.null (axis.args$x$at))
@@ -325,7 +330,7 @@ plotspc <- function  (object,
 
       axis (side = 1, at = max (abs (plot.args$xlim)) * c(-1.1, 1.1))
       do.call (axis, axis.args$x)
-      
+
       ## plot cut marks for x axis
       break.args <- modifyList (list (style = "zigzag"), break.args)
       break.args$axis <- NULL
@@ -354,12 +359,12 @@ plotspc <- function  (object,
           group.mins <- stacked$offsets
         else
           group.mins <- apply (spc[!duplicated (stacked$groups),, drop = FALSE], 1, min, na.rm = TRUE)
-    
+
         axis.args$y <- modifyList (list (at = stacked$offsets,
                                          labels = stacked$levels [!duplicated (stacked$levels)]),
                                    axis.args$y)
       }
-      
+
       axis.args$y <- modifyList (list (side = 2), axis.args$y)
       axis (side = 2, at = max (abs (plot.args$ylim)) * c(-1.1, 1.1))
       do.call (axis, axis.args$y)
@@ -369,26 +374,28 @@ plotspc <- function  (object,
 
     tmp <- title.args [! names (title.args) %in% c ("x","y", "ylab", "main", "sub")]
     tmp <- modifyList (tmp, as.list (title.args$x))
-    tmp <- modifyList (list (xlab = I(object@label$.wavelength), line = 2.5), tmp)
-    do.call (title, tmp)
     
+    tmp <- modifyList (list (xlab = object@label$.wavelength, line = 2.5), tmp)
+    do.call (title, tmp)
+    tmp$xlab <- NULL
+
     tmp <- title.args [! names (title.args) %in% c ("x","y", "xlab", "main", "sub")]
     tmp <- modifyList (tmp, as.list (title.args$y))
-    tmp <- modifyList (list (ylab = I(object@label$spc)), tmp)
+    tmp <- modifyList (list (ylab = object@label$spc), tmp)
     do.call (title, tmp)
-  
+    tmp$ylab <- NULL
+    
     tmp <- title.args [! names (title.args) %in% c ("x","y", "xlab", "ylab")]
     tmp <- modifyList (tmp, as.list (title.args [c ("main", "sub")]))
-    tmp <- modifyList (list (ylab = I(object@label$spc)), tmp)
     do.call (title, tmp)
   }
 
   ## plot the spectra -------------------------------------------------------------------------------
-  
+
   ## if necessary, recycle colors
   col <- rep (col, each = ceiling (nrow (spc) / length (col)), length.out = nrow (spc))
 
- 
+
   ## should the intensity zero be marked?
   if (!is.logical (zeroline) && !is.na (zeroline)){
     zeroline <- modifyList (list (h = unique (yoffset)), as.list (zeroline))
@@ -437,7 +444,7 @@ plotspc <- function  (object,
       border <- rep (border, length.out = length (groups))
 
       polygon.args$x <- c (x [[i]], rev (x [[i]]))
-      
+
       for (j in seq_along (groups)){
         tmp <- which (fill == groups [j])
         polygon.args$y <- c (spc[head(tmp, 1), ispc[[i]]], rev (spc [tail (tmp, 1), ispc[[i]]]))
@@ -468,11 +475,11 @@ plotspc <- function  (object,
     } else {
       for (j in seq_len (nrow (spc))){
         keep <- ! is.na (spc [j, ispc[[i]]])
-                
+
         lines.args$x <- x[[i]][keep]
         lines.args$y <- spc [j, ispc[[i]]] [keep]
         lines.args$col <- col [j]
-        
+
         do.call (lines, lines.args)
       }
     }
@@ -490,13 +497,13 @@ plotspc <- function  (object,
 
 ##' y Offsets for Stacked Plots
 ##' Calculate approriate \code{yoffset} values for stacking in \code{\link[hyperSpec]{plotspc}}.
-##' 
+##'
 ##' Usually, the \code{stacked} argument of \code{\link[hyperSpec]{plotspc}} will do fine, but if you
 ##' need fine control over the stacking, you may calculate the y offsets yourself.
 ##'
 ##' Empty levels of the stacking factor are dropped (as no stacking offset can be calculated in that
 ##' case.)
-##' 
+##'
 ##' @param x a \code{hyperSpec} object
 ##' @param min.zero if \code{TRUE}, the lesser of zero and the minimum intensity of the spectrum is
 ##' used as minimum.
@@ -511,25 +518,25 @@ plotspc <- function  (object,
 ##' @rdname plotspc
 ##' @export
 ##' @examples
-##' 
+##'
 ##' mean.pm.sd <- aggregate (chondro, chondro$clusters, mean_pm_sd)
-##' 
+##'
 ##' offset <- stacked.offsets (mean.pm.sd, ".aggregate")
 ##' plot (mean.pm.sd, fill.col = matlab.palette (3), fill = ".aggregate",
 ##'       stacked = ".aggregate")
-##'  	
+##'
 ##' plot (aggregate (chondro, chondro$clusters, mean), yoffset = offset$offsets,
 ##'       lines.args = list (lty = 2, lwd = 2), add = TRUE)
-##' 
+##'
 ##' barb <- do.call (collapse, barbiturates [1:3])
 ##' plot (barb, lines.args = list (type = "h"), stacked = TRUE,
 ##'       stacked.args = list (add.factor = .2))
-##' 
-##' 
+##'
+##'
 stacked.offsets <- function (x, stacked = TRUE,
                              min.zero = FALSE, add.factor = 0.05, add.sum = 0,
                              #tight = FALSE, TODO
-                             .spc = NULL){
+                             .spc = NULL, debuglevel = hy.getOption("debuglevel")){
   lvl <- NULL
 
   if (is.null (.spc))
@@ -540,23 +547,24 @@ stacked.offsets <- function (x, stacked = TRUE,
   else if (isTRUE (stacked))
     stacked <- row.seq (x)
 
-  ## cut stacked if necessary 
+  ## cut stacked if necessary
   if (length (stacked) != nrow (.spc)){
     stacked <- rep (stacked, length.out = nrow (.spc))
-    warning ("stacking variable recycled to ", nrow (.spc), " values.")
+    if (debuglevel >= 1L)
+      message ("stacking variable recycled to ", nrow (.spc), " values.")
   }
   if (is.numeric (stacked))
     stacked <- as.factor (stacked)
-  else if (!is.factor (stacked)) 
+  else if (!is.factor (stacked))
     stop ("stacked must be either TRUE, the name of the extra data column to use for grouping, a factor or a numeric.")
-  
+
   stacked <- droplevels (stacked)
   lvl <- levels (stacked)
   groups <- seq_along (levels (stacked))
   stacked <- as.numeric (stacked)
-  
+
   offset <- matrix (nrow = 2, ncol = length (groups))
-  
+
   for (i in groups)
     offset[, i] <- range (.spc [stacked == groups [i], ], na.rm = TRUE)
 
@@ -568,18 +576,48 @@ stacked.offsets <- function (x, stacked = TRUE,
 
   ## add some extra space
   offset [2,] <- offset [2, ] *  (1 + add.factor) + add.sum
-  
+
   offset <- c(-offset[1,], 0) + c (0, cumsum (offset[2,]))
-  
+
   list (offsets = offset [seq_along (groups)],
         groups = stacked,
         levels = if (is.null (lvl)) stacked else lvl
         )
 }
 
+##' @include unittest.R
+.test (stacked.offsets) <- function (){
+  context ("stacked.offsets")
 
-###  .axis.break - poor man's version of axis.break 
-.axis.break <- function (axis = 1,breakpos = NULL, ...) 
+  test_that("ranges do not overlap", {
+    spc <- do.call (collapse, barbiturates [1:3])
+    ofs <- stacked.offsets (spc)
+    spc <- spc + ofs$offsets
+    rngs <- apply (spc [[]], 1, range, na.rm = TRUE)
+
+    expect_equal (as.numeric (rngs), sort (rngs))
+  })
+
+  test_that("extra space", {
+    spc <- new ("hyperSpec", spc = matrix (c (0, 0, 2, 1 : 3), nrow = 3))
+
+    expect_equal (stacked.offsets (spc, add.factor = 0)$offsets, c (0, 1, 1))
+    expect_equal (stacked.offsets (spc, add.factor = 1)$offsets, c (0, 2, 4))
+    expect_equal (stacked.offsets (spc, add.factor = 0, add.sum = 1)$offsets, c (0, 2, 3))
+  })
+
+  test_that("min.zero", {
+    ofs <- stacked.offsets (flu, min.zero = TRUE, add.factor = 0)
+    expect_equal (ofs$offsets,
+                  c (0, cumsum (apply (flu [[- nrow (flu)]], 1, max))))
+  })
+
+
+
+}
+
+###  .axis.break - poor man's version of axis.break
+.axis.break <- function (axis = 1,breakpos = NULL, ...)
   mtext("//", at = breakpos, side = axis, padj = -1, adj = 0.5)
 
 ###.cut.ticks - pretty tick marks for cut axes
@@ -591,7 +629,7 @@ stacked.offsets <- function (x, stacked = TRUE,
   stopifnot (length (start.ranges) == length (end.ranges) &
              length (start.ranges) == length (offsets))
 
-  ## if (length (start.ranges) == 1)       
+  ## if (length (start.ranges) == 1)
 
 
   ## what part of the plot is occupied by each range?
@@ -606,7 +644,7 @@ stacked.offsets <- function (x, stacked = TRUE,
   at <- mapply (`-`, labels, offsets, SIMPLIFY = FALSE)
 
   ## cut marks
-  
+
   ## convert to device x in user coordinates
   start.ranges <- start.ranges - offsets
   end.ranges   <- end.ranges   - offsets
@@ -625,21 +663,25 @@ stacked.offsets <- function (x, stacked = TRUE,
     at [[i + 1]]     <- at     [[i + 1]][keep]
     labels [[i + 1]] <- labels [[i + 1]][keep]
   }
-  
+
   list (labels = as.numeric (unlist (labels)),
         at     = as.numeric (unlist (at)),
         cut    = cutmarks)
 }
 
-##' @include hyperspec-package.R
+##' @include unittest.R
 .test (.cut.ticks) <- function (){
+  context (".cut.ticks")
+
   ## bugfix:
   ## plotspc (paracetamol, wl.range = c (min ~ 1800, 2800 ~ max), xoffset = 900)
   ## had 2600 1/cm label printed in low wavelength range
-  checkEqualsNumeric (.cut.ticks (start.ranges = c (96.7865, 2799.86),
-                                  end.ranges = c(1799.95, 3200.07),
-                                  offsets = c (0, 900),
-                                  nticks = 10)$labels,
-                      c (seq (0, 1800, 200), seq (2800, 3400, 200))
-                      )
+  test_that("labels not too far outside wl.range",{
+    expect_equal (.cut.ticks (start.ranges = c (96.7865, 2799.86),
+                              end.ranges = c(1799.95, 3200.07),
+                              offsets = c (0, 900),
+                              nticks = 10)$labels,
+                  c (seq (0, 1800, 200), seq (2800, 3400, 200))
+    )
+  })
 }
